﻿using System;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;

namespace UsingCustomLabel_Xamarin
{
	public class MyCustomChartDelegate : IGChartViewDelegate
	{
		public MyCustomChartDelegate ()
		{
		}

		// We need to filter out that we are looking at the Y-axis. I know in this case that my Y axis has
		// a key value of "y".
		public override string ResolveLabelForAxis (IGChartView chartView, IGAxis axis, NSObject item)
		{
			if (axis.Key.Equals ("y")) {
				// I want to make any number > 1000 into a "k" denomination, so if the string is 4 or more characters then clip it, add a k and return.
				NSNumber num = (NSNumber)item;

				String longString = num.ToString();

				String s = longString.ToString ();

				if (s.Length > 3) {
					s = s.Substring (0, s.Length - 3);
					s = s + "K";
				}
				return s;
			}


			// Since we are overriding this method we also need to handle the X - axis labels. Since
			// IGLineSeries is a CategorySeries and the x - axis is the category axis in this case, we can
			// cast the item to a IGDataPoint and return the label.
			//IGDataPoint* pt = (IGDataPoint*)item;
			//return pt.label;

			// But just doing that isn't any fun. So instead lets get the underlying data object and make a better label.

			IGDataPoint pt = (IGDataPoint)item;

			IGColumnSeries colSeries = (IGColumnSeries)chartView.Series [0];

			IGCategorySeriesDataSourceHelper helper = (IGCategorySeriesDataSourceHelper)colSeries.DataSource;

			MyDataClass dataObj = (MyDataClass)this.ObjectForDataPointInSeries (pt, helper ,colSeries);

			string firstInitial = dataObj.FirstName.Substring (0, 1);

			return firstInitial + ". " + dataObj.LastName;
		}

		NSObject ObjectForDataPointInSeries(IGDataPoint point, IGSeriesDataSourceHelper helper, IGSeries series)
		{
			int index = -1;

			for (int i = 0; i < series.DataPoints.Count; i++) 
			{
				IGDataPoint tempItem =(IGDataPoint)  series.DataPoints.GetItem<IGDataPoint> (i);
				if (tempItem == point) {
					index = i;
					break;
				}
			}

			if (index>=0 && index<= helper.Data.Length)
			{
				return helper.Data[index];
			}

			return null;
		}
	}
}

